/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#ifndef _GCTL_MAG_KERNEL_SHC_H
#define _GCTL_MAG_KERNEL_SHC_H

#include "gm_data.h"
#include "gctl/utility/progress_bar.h"

namespace gctl
{
    /**
     * @brief Calculate the magnetic componments using the spherical harmonic coefficients.
     * 
     * @param out_obs Output magnetic field data. Directional components are stored accordingly.
     * @param sd Spherical harmonic coefficients.
     * @param obsp The observation points.
     * @param verbose Output info level.
     */
    void magobser(array<point3dc> &out_obs, const shc_data &sd, const array<point3ds>& obsp, verbose_type_e verbose = FullMsg);
};

#endif // _GCTL_MAG_KERNEL_SHC_H